@@ -32,6 +32,7 @@ import re
 import types
 import dill
 import base64
+from io import BytesIO
 
 
 class FeatureStore():
@@ -471,13 +472,19 @@ class FeatureStore():
             'to_date': pd.Timestamp(to_date).isoformat(),
             'freq': freq,
             'time_travel': time_travel,
-            'entity': ','.join(entity) if entity else None
+            'entity': ','.join(entity) if entity else None,
+            'format': 'parquet'
         }
+        headers = self._api_headers()
+        # Set this header to allow response to be returned as Parquet
+        headers['Accept'] = 'application/octet-stream'
         response = requests.get(
-            url, params=params, headers=self._api_headers())
+            url, params=params, headers=headers)
         response.raise_for_status()
 
-        df = pd.DataFrame(response.json())
+        # Load parquet response
+        buffer = BytesIO(response.content)
+        df = pd.read_parquet(buffer)
         if df.empty:
             return pd.DataFrame(
                 {
@@ -524,19 +531,20 @@ class FeatureStore():
         feature_id = self.get_feature_id(feature)
         url = self.endpoint + f'timeseries/{feature_id}'
 
-        # Convert payload to JSON
-        payload = json.loads(df.to_json(orient='records'))
         headers = self._api_headers()
 
         if len(df) > 10:
-            # Compress the payload
-            payload = gzip.compress(json.dumps(payload).encode('utf-8'))
-            headers['Content-Type'] = 'application/json'
-            headers['Content-Encoding'] = 'gzip'
+            # Send the payload as parquet
+            buffer = BytesIO()
+            df.to_parquet(buffer, index=False, allow_truncated_timestamps=True, compression='gzip')
+            buffer.seek(0)
+            headers['Content-Type'] = 'application/octet-stream'
             response = requests.post(
-                url, data=payload, headers=headers
+                url, data=buffer.read(), headers=headers
             )
         else:
+            # Convert payload to JSON
+            payload = json.loads(df.to_json(orient='records'))
             response = requests.post(
                 url, json=payload, headers=headers
             )
